@@ -1,4 +1,4 @@
-use ansi_term::{Color, Style};
+use yansi::Color;
 
 /// Print a warning to stderr. If `enable_styles` is true, then a yellow
 /// message will be printed.
@@ -6,16 +6,20 @@ pub fn print_warning(enable_styles: bool, message: &str) {
     print_msg(enable_styles, message, "Warning: ", Color::Yellow);
 }
 
-/// Print an error to stderr. If `enable_styles` is true, then a red message
-/// will be printed.
-pub fn print_error(enable_styles: bool, message: &str) {
-    print_msg(enable_styles, message, "Error: ", Color::Red);
+/// Print an anyhow error to stderr. If `enable_styles` is true, then a red
+/// message will be printed.
+pub fn print_error(enable_styles: bool, error: &anyhow::Error) {
+    print_msg(
+        enable_styles,
+        &format!("{:?}", error),
+        "Error: ",
+        Color::Red,
+    );
 }
 
 fn print_msg(enable_styles: bool, message: &str, prefix: &'static str, color: Color) {
     if enable_styles {
-        let style = Style::new().fg(color);
-        eprintln!("{}{}", style.paint(prefix), style.paint(message));
+        eprintln!("{}{}", color.paint(prefix), color.paint(message));
     } else {
         eprintln!("{}", message);
     }
