@@ -10,9 +10,9 @@ use std::{
 use assert_cmd::prelude::*;
 use predicates::{
     boolean::PredicateBooleanExt,
-    prelude::predicate::str::{contains, diff, is_empty},
+    prelude::predicate::str::{contains, diff, is_empty, is_match},
 };
-use tempfile::{Builder, TempDir};
+use tempfile::{Builder as TempfileBuilder, TempDir};
 
 // TODO: Should be 'cache::CACHE_DIR_ENV_VAR'. This requires to have a library crate for the logic.
 static CACHE_DIR_ENV_VAR: &str = "TEALDEER_CACHE_DIR";
@@ -31,13 +31,22 @@ struct TestEnv {
 impl TestEnv {
     fn new() -> Self {
         TestEnv {
-            cache_dir: Builder::new().prefix(".tldr.test.cache").tempdir().unwrap(),
-            config_dir: Builder::new().prefix(".tldr.test.conf").tempdir().unwrap(),
-            custom_pages_dir: Builder::new()
+            cache_dir: TempfileBuilder::new()
+                .prefix(".tldr.test.cache")
+                .tempdir()
+                .unwrap(),
+            config_dir: TempfileBuilder::new()
+                .prefix(".tldr.test.conf")
+                .tempdir()
+                .unwrap(),
+            custom_pages_dir: TempfileBuilder::new()
                 .prefix(".tldr.test.custom-pages")
                 .tempdir()
                 .unwrap(),
-            input_dir: Builder::new().prefix(".tldr.test.input").tempdir().unwrap(),
+            input_dir: TempfileBuilder::new()
+                .prefix(".tldr.test.input")
+                .tempdir()
+                .unwrap(),
             default_features: true,
             features: vec![],
         }
@@ -131,7 +140,7 @@ fn test_missing_cache() {
         .args(["sl"])
         .assert()
         .failure()
-        .stderr(contains("Cache not found. Please run `tldr --update`."));
+        .stderr(contains("Page cache not found. Please run `tldr --update`"));
 }
 
 #[test]
@@ -143,7 +152,7 @@ fn test_update_cache() {
         .args(["sl"])
         .assert()
         .failure()
-        .stderr(contains("Cache not found. Please run `tldr --update`."));
+        .stderr(contains("Page cache not found. Please run `tldr --update`"));
 
     testenv
         .command()
@@ -263,9 +272,53 @@ fn test_cache_location_not_a_directory() {
         .assert()
         .failure()
         .stderr(contains(format!(
-            "Path specified by ${} is not a directory.",
-            CACHE_DIR_ENV_VAR
-        )));
+            "Cache directory path `{}` is not a directory",
+            internal_file.display(),
+        )))
+        .stderr(contains(
+            "Warning: The $TEALDEER_CACHE_DIR env variable is deprecated",
+        ));
+}
+
+#[test]
+fn test_cache_location_source() {
+    let testenv = TestEnv::new();
+    let default_cache_dir = testenv.cache_dir.path();
+    let tmp_cache_dir = TempfileBuilder::new()
+        .prefix(".tldr.test.cache_dir")
+        .tempdir()
+        .unwrap();
+
+    // Source: Default (OS convention)
+    let mut command = testenv.command();
+    command.env_remove(CACHE_DIR_ENV_VAR);
+    command
+        .arg("--show-paths")
+        .assert()
+        .success()
+        .stdout(is_match("\nCache dir:        [^(]* \\(OS convention\\)\n").unwrap());
+
+    // Source: Config variable
+    let mut command = testenv.command();
+    command.env_remove(CACHE_DIR_ENV_VAR);
+    testenv.write_config(format!(
+        "[directories]\ncache_dir = '{}'",
+        tmp_cache_dir.path().to_str().unwrap(),
+    ));
+    command
+        .arg("--show-paths")
+        .assert()
+        .success()
+        .stdout(is_match("\nCache dir:        [^(]* \\(config file\\)\n").unwrap());
+
+    // Source: Env var
+    let mut command = testenv.command();
+    command.env(CACHE_DIR_ENV_VAR, default_cache_dir.to_str().unwrap());
+    command
+        .arg("--show-paths")
+        .assert()
+        .success()
+        .stdout(is_match("\nCache dir:        [^(]* \\(env variable\\)\n").unwrap());
 }
 
 #[test]
@@ -513,12 +566,18 @@ fn test_pager_flag_enable() {
 fn test_list_flag_rendering() {
     let testenv = TestEnv::new();
 
+    // set custom pages directory
+    testenv.write_config(format!(
+        "[directories]\ncustom_pages_dir = '{}'",
+        testenv.custom_pages_dir.path().to_str().unwrap()
+    ));
+
     testenv
         .command()
         .args(["--list"])
         .assert()
         .failure()
-        .stderr(contains("Cache not found. Please run `tldr --update`."));
+        .stderr(contains("Page cache not found. Please run `tldr --update`"));
 
     testenv.add_entry("foo", "");
 
@@ -532,13 +591,17 @@ fn test_list_flag_rendering() {
     testenv.add_entry("bar", "");
     testenv.add_entry("baz", "");
     testenv.add_entry("qux", "");
+    testenv.add_page_entry("faz", "");
+    testenv.add_page_entry("bar", "");
+    testenv.add_page_entry("fiz", "");
+    testenv.add_patch_entry("buz", "");
 
     testenv
         .command()
         .args(["--list"])
         .assert()
         .success()
-        .stdout("bar\nbaz\nfoo\nqux\n");
+        .stdout("bar\nbaz\nfaz\nfiz\nfoo\nqux\n");
 }
 
 #[test]
@@ -551,7 +614,7 @@ fn test_autoupdate_cache() {
         .args(["--list"])
         .assert()
         .failure()
-        .stderr(contains("Cache not found. Please run `tldr --update`."));
+        .stderr(contains("Page cache not found. Please run `tldr --update`"));
 
     let config_file_path = testenv.config_dir.path().join("config.toml");
     let cache_file_path = testenv.cache_dir.path().join(TLDR_PAGES_DIR);
@@ -624,7 +687,7 @@ fn test_custom_page_overwrites() {
         .stdout(diff(expected));
 }
 
-/// End-End test to ensure that .patch files are appened to pages in the cache_dir
+/// End-End test to ensure that .patch files are appended to pages in the cache_dir
 #[test]
 fn test_custom_patch_appends_to_common() {
     let testenv = TestEnv::new();
